# WTFML: Well That's Fantastic Machine Learning
pronounced as: w-t-f-m-l

WTFML is WIP.

Origin of the name:

```
abhishek  11:21 AM
i cant think of any good names
wtf

friend1:  11:22 AM
WTF is a good name
:joy:

abhishek  11:22 AM
well, it is actually! 
wtfml

friend2  11:23 AM
:rolling_on_the_floor_laughing:

abhishek  11:23 AM
very nice!
ill use it

abhishek  11:24 AM
WTFML: Well That’s Fantastic Machine Learning library
```
